pymusepipe package
==================

Submodules
----------

pymusepipe.align\_pipe module
-----------------------------

.. automodule:: pymusepipe.align_pipe
   :members:
   :undoc-members:
   :show-inheritance:

pymusepipe.check\_pipe module
-----------------------------

.. automodule:: pymusepipe.check_pipe
   :members:
   :undoc-members:
   :show-inheritance:

pymusepipe.combine module
-------------------------

.. automodule:: pymusepipe.combine
   :members:
   :undoc-members:
   :show-inheritance:

pymusepipe.config\_pipe module
------------------------------

.. automodule:: pymusepipe.config_pipe
   :members:
   :undoc-members:
   :show-inheritance:

pymusepipe.create\_sof module
-----------------------------

.. automodule:: pymusepipe.create_sof
   :members:
   :undoc-members:
   :show-inheritance:

pymusepipe.cube\_convolve module
--------------------------------

.. automodule:: pymusepipe.cube_convolve
   :members:
   :undoc-members:
   :show-inheritance:

pymusepipe.emission\_lines module
---------------------------------

.. automodule:: pymusepipe.emission_lines
   :members:
   :undoc-members:
   :show-inheritance:

pymusepipe.graph\_pipe module
-----------------------------

.. automodule:: pymusepipe.graph_pipe
   :members:
   :undoc-members:
   :show-inheritance:

pymusepipe.init\_musepipe module
--------------------------------

.. automodule:: pymusepipe.init_musepipe
   :members:
   :undoc-members:
   :show-inheritance:

pymusepipe.mpdaf\_pipe module
-----------------------------

.. automodule:: pymusepipe.mpdaf_pipe
   :members:
   :undoc-members:
   :show-inheritance:

pymusepipe.musepipe module
--------------------------

.. automodule:: pymusepipe.musepipe
   :members:
   :undoc-members:
   :show-inheritance:

pymusepipe.prep\_recipes\_pipe module
-------------------------------------

.. automodule:: pymusepipe.prep_recipes_pipe
   :members:
   :undoc-members:
   :show-inheritance:

pymusepipe.recipes\_pipe module
-------------------------------

.. automodule:: pymusepipe.recipes_pipe
   :members:
   :undoc-members:
   :show-inheritance:

pymusepipe.target\_sample module
--------------------------------

.. automodule:: pymusepipe.target_sample
   :members:
   :undoc-members:
   :show-inheritance:

pymusepipe.util\_pipe module
----------------------------

.. automodule:: pymusepipe.util_pipe
   :members:
   :undoc-members:
   :show-inheritance:

pymusepipe.version module
-------------------------

.. automodule:: pymusepipe.version
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pymusepipe
   :members:
   :undoc-members:
   :show-inheritance:
